@@ -9,6 +9,7 @@
 
 #include <common.h>
 #include <init.h>
+#include <sizes.h>
 
 #include <asm/io.h>
 #include <asm/barebox-arm.h>
@@ -23,11 +24,11 @@
 #define PLL_VALUE		(((CPU_SPEED * 2) / MAIN_CLOCK) << 24)
 #define SDRAM_REFRESH_RATE	(64 * (BUS_SPEED / (8192 * 1000)))
 
-void __naked __bare_init reset(void)
+void __naked __bare_init barebox_arm_reset_vector(void)
 {
 	u32 tmp;
 
-	common_reset();
+	arm_cpu_lowlevel_init();
 
 	/* Setup base clock */
 	writel(SYSCON3_CLKCTL0 | SYSCON3_CLKCTL1, SYSCON3);
@@ -52,5 +53,5 @@ void __naked __bare_init reset(void)
 	writel(SDCONF_CASLAT_3 | SDCONF_SIZE_256 | SDCONF_WIDTH_16 |
 	       SDCONF_CLKCTL | SDCONF_ACTIVE, SDCONF);
 
-	board_init_lowlevel_return();
+	barebox_arm_entry(SDRAM0_BASE, SZ_32M, 0);
 }
