@@ -25,10 +25,8 @@
 # include <mach/iomux-imx28.h>
 #endif
 
+#include <asm-generic/gpio.h>
+
 void imx_gpio_mode(uint32_t);
-void gpio_set_value(unsigned, int);
-int gpio_direction_input(unsigned);
-int gpio_direction_output(unsigned, int);
-int gpio_get_value(unsigned);
 
 #endif /* __ASM_MACH_GPIO_H */
