@@ -355,18 +355,25 @@ static int atmci_start_cmd(struct atmel_mci *host, struct mci_cmd *cmd,
 	return 0;
 }
 
+static int atmci_card_present(struct mci_host *mci)
+{
+	struct atmel_mci *host = to_mci_host(mci);
+	struct atmel_mci_platform_data *pd = host->hw_dev->platform_data;
+	int ret;
+
+	/* No gpio, assume card is present */
+	if (!gpio_is_valid(pd->detect_pin))
+		return 1;
+
+	ret = gpio_get_value(pd->detect_pin);
+
+	return ret == 0 ? 1 : 0;
+}
+
 /** init the host interface */
 static int atmci_reset(struct mci_host *mci, struct device_d *mci_dev)
 {
-	int ret;
 	struct atmel_mci *host = to_mci_host(mci);
-	struct atmel_mci_platform_data *pd = host->hw_dev->platform_data;
-
-	ret = gpio_get_value(pd->detect_pin);
-	dev_dbg(host->hw_dev, "card %sdetected\n", ret != 0 ? "not " : "");
-
-	if (pd->detect_pin && ret == 1)
-		return -ENODEV;
 
 	clk_enable(host->clk);
 	atmci_writel(host, ATMCI_DTOR, 0x7f);
@@ -554,6 +561,7 @@ static int atmci_probe(struct device_d *hw_dev)
 	host->mci.send_cmd = atmci_request;
 	host->mci.set_ios = atmci_set_ios;
 	host->mci.init = atmci_reset;
+	host->mci.card_present = atmci_card_present;
 	host->mci.hw_dev = hw_dev;
 
 	if (pd->bus_width >= 4)
