@@ -5,11 +5,9 @@
 #include <errno.h>
 #include <asm/byteorder.h>
 
-extern struct fdt_header *barebox_fdt;
-
 int fdt_print(struct fdt_header *working_fdt, const char *pathp);
 
-struct fdt_header *of_get_fixed_tree(void);
+struct fdt_header *of_get_fixed_tree(struct fdt_header *fdt);
 int of_fix_tree(struct fdt_header *fdt);
 int of_register_fixup(int (*fixup)(struct fdt_header *));
 
@@ -107,6 +105,12 @@ int of_machine_is_compatible(const char *compat);
 void of_print_nodes(struct device_node *node, int indent);
 int of_probe(void);
 int of_parse_dtb(struct fdt_header *fdt);
+void of_free(struct device_node *node);
+int of_unflatten_dtb(struct fdt_header *fdt);
+struct device_node *of_new_node(struct device_node *parent, const char *name);
+struct property *of_new_property(struct device_node *node, const char *name,
+		const void *data, int len);
+void of_delete_property(struct property *pp);
 
 int of_property_read_string(struct device_node *np, const char *propname,
 				const char **out_string);
@@ -119,6 +123,7 @@ struct device_node *of_get_root_node(void);
 int of_alias_get_id(struct device_node *np, const char *stem);
 int of_device_is_stdout_path(struct device_d *dev);
 const char *of_get_model(void);
+void *of_flatten_dtb(void);
 #else
 static inline int of_parse_partitions(const char *cdevname,
 					  struct device_node *node)
@@ -145,6 +150,11 @@ static inline const char *of_get_model(void)
 {
 	return NULL;
 }
+
+static inline void *of_flatten_dtb(void)
+{
+	return NULL;
+}
 #endif
 
 #endif /* __OF_H */
